@@ -15,22 +15,18 @@ class FetcherException(Exception):
 
 
 class Fetcher(object):
-    _providers = {
-        'gerrit': Gerrit,
-        'github': GitHub,
-        'gitlab': GitLab
-    }
+    _providers = {"gerrit": Gerrit, "github": GitHub, "gitlab": GitLab}
 
     def __init__(self, config=None):
         if config is None:
-            raise FetcherException('config invalid')
+            raise FetcherException("config invalid")
 
         self._config = config
 
     def run(self):
-        for item in self._config.repo_hosts:
+        for item in self._config.repo_host:
             try:
                 provider = self._providers[item]()
-                provider.run(self._config.repo_langs, self._config.repo_count)
+                provider.run(self._config.repo_lang, self._config.repo_count)
             except Exception as e:
-                raise FetcherException('run failed %s' % str(e))
+                raise FetcherException("failed to run: %s" % str(e))
